@@ -38,27 +38,30 @@
  */
 struct multi_tcp
 {
-  struct event_set *es;
-  struct event_set_return *esr;
-  int n_esr;
-  int maxevents;
-  unsigned int tun_rwflags;
+    struct event_set *es;
+    struct event_set_return *esr;
+    int n_esr;
+    int maxevents;
+    unsigned int tun_rwflags;
 #ifdef ENABLE_MANAGEMENT
-  unsigned int management_persist_flags;
+    unsigned int management_persist_flags;
 #endif
 };
 
 struct multi_instance;
 struct context;
 
-struct multi_tcp *multi_tcp_init (int maxevents, int *maxclients);
-void multi_tcp_free (struct multi_tcp *mtcp);
-void multi_tcp_dereference_instance (struct multi_tcp *mtcp, struct multi_instance *mi);
+struct multi_tcp *multi_tcp_init(int maxevents, int *maxclients);
 
-bool multi_tcp_instance_specific_init (struct multi_context *m, struct multi_instance *mi);
-void multi_tcp_instance_specific_free (struct multi_instance *mi);
+void multi_tcp_free(struct multi_tcp *mtcp);
 
-void multi_tcp_link_out_deferred (struct multi_context *m, struct multi_instance *mi);
+void multi_tcp_dereference_instance(struct multi_tcp *mtcp, struct multi_instance *mi);
+
+bool multi_tcp_instance_specific_init(struct multi_context *m, struct multi_instance *mi);
+
+void multi_tcp_instance_specific_free(struct multi_instance *mi);
+
+void multi_tcp_link_out_deferred(struct multi_context *m, struct multi_instance *mi);
 
 
 /**************************************************************************/
@@ -68,10 +71,10 @@ void multi_tcp_link_out_deferred (struct multi_context *m, struct multi_instance
  *
  * @param top - Top-level context structure.
  */
-void tunnel_server_tcp (struct context *top);
+void tunnel_server_tcp(struct context *top);
 
 
-void multi_tcp_delete_event (struct multi_tcp *mtcp, event_t event);
+void multi_tcp_delete_event(struct multi_tcp *mtcp, event_t event);
 
-#endif
-#endif
+#endif /* if P2MP_SERVER */
+#endif /* ifndef MTCP_H */
