@@ -32,28 +32,33 @@
 #define PCT_SRC  1
 #define PCT_DEST 2
 static inline bool
-pf_c2c_test (const struct context *src, const struct context *dest, const char *prefix)
+pf_c2c_test(const struct context *src, const struct context *dest, const char *prefix)
 {
-  bool pf_cn_test (struct pf_set *pfs, const struct tls_multi *tm, const int type, const char *prefix);
-  return  (!src->c2.pf.enabled  || pf_cn_test (src->c2.pf.pfs,  dest->c2.tls_multi, PCT_DEST, prefix))
-       && (!dest->c2.pf.enabled || pf_cn_test (dest->c2.pf.pfs, src->c2.tls_multi,  PCT_SRC,  prefix));
+    bool pf_cn_test(struct pf_set *pfs, const struct tls_multi *tm, const int type, const char *prefix);
+
+    return (!src->c2.pf.enabled  || pf_cn_test(src->c2.pf.pfs,  dest->c2.tls_multi, PCT_DEST, prefix))
+           && (!dest->c2.pf.enabled || pf_cn_test(dest->c2.pf.pfs, src->c2.tls_multi,  PCT_SRC,  prefix));
 }
 
 static inline bool
-pf_addr_test (const struct context *src, const struct mroute_addr *dest, const char *prefix)
+pf_addr_test(const struct context *src, const struct mroute_addr *dest, const char *prefix)
 {
-  bool pf_addr_test_dowork (const struct context *src, const struct mroute_addr *dest, const char *prefix);
+    bool pf_addr_test_dowork(const struct context *src, const struct mroute_addr *dest, const char *prefix);
 
-  if (src->c2.pf.enabled)
-    return pf_addr_test_dowork (src, dest, prefix);
-  else
-    return true;
+    if (src->c2.pf.enabled)
+    {
+        return pf_addr_test_dowork(src, dest, prefix);
+    }
+    else
+    {
+        return true;
+    }
 }
 
 static inline bool
-pf_kill_test (const struct pf_set *pfs)
+pf_kill_test(const struct pf_set *pfs)
 {
-  return pfs->kill;
+    return pfs->kill;
 }
 
-#endif
+#endif /* if defined(ENABLE_PF) && !defined(PF_INLINE_H) */
