@@ -5,7 +5,7 @@
  *             packet encryption, packet authentication, and
  *             packet compression.
  *
- *  Copyright (C) 2002-2010 OpenVPN Technologies, Inc. <sales@openvpn.net>
+ *  Copyright (C) 2002-2017 OpenVPN Technologies, Inc. <sales@openvpn.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License version 2
@@ -34,26 +34,27 @@
 typedef void (*post_fork_cleanup_func_t)(void *arg);
 
 struct port_share {
-  /* Foreground's socket to background process */
-  socket_descriptor_t foreground_fd;
+    /* Foreground's socket to background process */
+    socket_descriptor_t foreground_fd;
 
-  /* Process ID of background process */
-  pid_t background_pid;
+    /* Process ID of background process */
+    pid_t background_pid;
 };
 
 extern struct port_share *port_share;
 
-struct port_share *port_share_open (const char *host,
-				    const int port,
-				    const int max_initial_buf,
-				    const char *journal_dir);
+struct port_share *port_share_open(const char *host,
+                                   const char *port,
+                                   const int max_initial_buf,
+                                   const char *journal_dir);
 
-void port_share_close (struct port_share *ps);
-void port_share_abort (struct port_share *ps);
+void port_share_close(struct port_share *ps);
 
-bool is_openvpn_protocol (const struct buffer *buf);
+void port_share_abort(struct port_share *ps);
 
-void port_share_redirect (struct port_share *ps, const struct buffer *head, socket_descriptor_t sd);
+bool is_openvpn_protocol(const struct buffer *buf);
 
-#endif
-#endif
+void port_share_redirect(struct port_share *ps, const struct buffer *head, socket_descriptor_t sd);
+
+#endif /* if PORT_SHARE */
+#endif /* ifndef PS_H */
